pub struct AddrHashPrefixMatches {
pub addr_type: OutputType,
pub prefix: String,
pub truncated: bool,
pub addresses: Vec<Addr>,
}Fields
addr_type: OutputTypeprefix: Stringtruncated: booladdresses: Vec<Addr>Trait Implementations
Sourceimpl Debug for AddrHashPrefixMatches
impl Debug for AddrHashPrefixMatches
Sourceimpl<'de> Deserialize<'de> for AddrHashPrefixMatches
impl<'de> Deserialize<'de> for AddrHashPrefixMatches
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AddrHashPrefixMatches, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AddrHashPrefixMatches, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddrHashPrefixMatches
impl JsonSchema for AddrHashPrefixMatches
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AddrHashPrefixMatches
impl Serialize for AddrHashPrefixMatches
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more